# -*- coding: utf-8 -*-
from django.contrib import admin
from django import forms
from django.utils.translation import ugettext_lazy as _

from .models import CallerNumList, ProviderRatecard, CustomerRatecard, CustomerPrefixRate, ProviderPrefixRate, CustomerDestinationRate, ProviderDestinationRate, CustomerCountryTypeRate, ProviderCountryTypeRate, CustomerCountryRate, ProviderCountryRate, CustomerRegionTypeRate, ProviderRegionTypeRate, CustomerRegionRate, ProviderRegionRate, CustomerDefaultRate, ProviderDefaultRate

class CallerNumListAdminForm(forms.ModelForm):

    class Meta:
        model = CallerNumList
        fields = '__all__'


class CallerNumListAdmin(admin.ModelAdmin):
    form = CallerNumListAdminForm
    list_display = ['name', 'slug', 'callerid_filter']
    readonly_fields = ['slug',]
    filter_horizontal = ('destination',)

admin.site.register(CallerNumList, CallerNumListAdmin)


class ProviderPrefixRateInline(admin.TabularInline):
    model = ProviderPrefixRate
    fields = ['prefix', 'destnum_length', 'r_rate', 'r_block_min_duration', 'r_minimal_time', 'r_init_block', 'status']
    #formset = CustomerPrefixRateFormSet
    max_num = 40
    extra = 0


class ProviderDestinationRateInline(admin.TabularInline):
    model = ProviderDestinationRate
    fields = ['destination', 'r_rate', 'r_block_min_duration', 'r_minimal_time', 'r_init_block', 'status']
    #formset = CustomerPrefixRateFormSet
    max_num = 40
    extra = 0


class ProviderCountryTypeRateInline(admin.TabularInline):
    model = ProviderCountryTypeRate
    fields = ['country', 'type', 'r_rate', 'r_block_min_duration', 'r_minimal_time', 'r_init_block', 'status']
    #formset = CustomerPrefixRateFormSet
    max_num = 40
    extra = 0


class ProviderCountryRateInline(admin.TabularInline):
    model = ProviderCountryRate
    fields = ['country', 'r_rate', 'r_block_min_duration', 'r_minimal_time', 'r_init_block', 'status']
    #formset = CustomerPrefixRateFormSet
    max_num = 40
    extra = 0


class ProviderRegionTypeRateInline(admin.TabularInline):
    model = ProviderRegionTypeRate
    fields = ['region', 'type', 'r_rate', 'r_block_min_duration', 'r_minimal_time', 'r_init_block', 'status']
    #formset = CustomerPrefixRateFormSet
    max_num = 40
    extra = 0


class ProviderRegionRateInline(admin.TabularInline):
    model = ProviderRegionRate
    fields = ['region', 'r_rate', 'r_block_min_duration', 'r_minimal_time', 'r_init_block', 'status']
    #formset = CustomerPrefixRateFormSet
    max_num = 40
    extra = 0


class ProviderDefaultRateInline(admin.TabularInline):
    model = ProviderDefaultRate
    fields = ['r_rate', 'r_block_min_duration', 'r_minimal_time', 'r_init_block', 'status']
    #formset = CustomerPrefixRateFormSet
    max_num = 40
    extra = 0


class ProviderRatecardAdminForm(forms.ModelForm):
    # date_validity = DateTimeRangeField(widget=RangeWidget(AdminDateTime())

    class Meta:
        model = ProviderRatecard
        fields = '__all__'


class ProviderRatecardAdmin(admin.ModelAdmin):
    form = ProviderRatecardAdminForm
    list_display = ['id', 'name', 'rc_type', 'callerid_list', 'status', 'provider_prefix', 'estimated_quality', 'date_start', 'date_end',]
    readonly_fields = ['id', 'slug', 'status_changed', 'created', 'modified']
    fieldsets = (
        (_(u'Ratecard details'), {
            'fields': (
                ('name', 'status'),
                ('rc_type', 'callerid_list'),
                ('provider_prefix', 'estimated_quality'),
                ('date_start', 'date_end'),
            ),
        }),
        (_(u'More -- view description and event dates'), {
            'fields': (
                'description',
                ('created', 'modified'),
                'status_changed',
            ),
            'classes': ('collapse',),
        }),
    )
    list_filter = ['status', 'rc_type']
    search_fields = ['description', '^name']
    inlines = [
        ProviderPrefixRateInline,
        ProviderDestinationRateInline,
        ProviderCountryTypeRateInline,
        ProviderCountryRateInline,
        ProviderRegionTypeRateInline,
        ProviderRegionRateInline,
        ProviderDefaultRateInline,
    ]

admin.site.register(ProviderRatecard, ProviderRatecardAdmin)


class CustomerPrefixRateInline(admin.TabularInline):
    model = CustomerPrefixRate
    fields = ['prefix', 'destnum_length', 'r_rate', 'r_block_min_duration', 'r_minimal_time', 'r_init_block', 'status']
    #formset = CustomerPrefixRateFormSet
    max_num = 40
    extra = 0


class CustomerDestinationRateInline(admin.TabularInline):
    model = CustomerDestinationRate
    fields = ['destination', 'r_rate', 'r_block_min_duration', 'r_minimal_time', 'r_init_block', 'status']
    #formset = CustomerPrefixRateFormSet
    max_num = 40
    extra = 0


class CustomerCountryTypeRateInline(admin.TabularInline):
    model = CustomerCountryTypeRate
    fields = ['country', 'type', 'r_rate', 'r_block_min_duration', 'r_minimal_time', 'r_init_block', 'status']
    #formset = CustomerPrefixRateFormSet
    max_num = 40
    extra = 0


class CustomerCountryRateInline(admin.TabularInline):
    model = CustomerCountryRate
    fields = ['country', 'r_rate', 'r_block_min_duration', 'r_minimal_time', 'r_init_block', 'status']
    #formset = CustomerPrefixRateFormSet
    max_num = 40
    extra = 0


class CustomerRegionTypeRateInline(admin.TabularInline):
    model = CustomerRegionTypeRate
    fields = ['region', 'type', 'r_rate', 'r_block_min_duration', 'r_minimal_time', 'r_init_block', 'status']
    #formset = CustomerPrefixRateFormSet
    max_num = 40
    extra = 0


class CustomerRegionRateInline(admin.TabularInline):
    model = CustomerRegionRate
    fields = ['region', 'r_rate', 'r_block_min_duration', 'r_minimal_time', 'r_init_block', 'status']
    #formset = CustomerPrefixRateFormSet
    max_num = 40
    extra = 0


class CustomerDefaultRateInline(admin.TabularInline):
    model = CustomerDefaultRate
    fields = ['r_rate', 'r_block_min_duration', 'r_minimal_time', 'r_init_block', 'status']
    #formset = CustomerPrefixRateFormSet
    max_num = 40
    extra = 0


class CustomerRatecardAdminForm(forms.ModelForm):

    class Meta:
        model = CustomerRatecard
        fields = '__all__'


class CustomerRatecardAdmin(admin.ModelAdmin):
    form = CustomerRatecardAdminForm
    list_display = ['id', 'name', 'rc_type', 'callerid_list', 'status', 'date_start', 'date_end']
    readonly_fields = ['id', 'slug', 'status_changed', 'created', 'modified']
    fieldsets = (
        (_(u'Ratecard details'), {
            'fields': (
                ('name', 'status'),
                ('rc_type', 'callerid_list'),
                ('date_start', 'date_end'),
            ),
        }),
        (_(u'More -- view description and event dates'), {
            'fields': (
                'description',
                ('created', 'modified'),
                'status_changed',
            ),
            'classes': ('collapse',),
        }),
    )
    list_filter = ['status', 'rc_type', 'callerid_list']
    search_fields = ['description', '^name']
    inlines = [
        CustomerPrefixRateInline,
        CustomerDestinationRateInline,
        CustomerCountryTypeRateInline,
        CustomerCountryRateInline,
        CustomerRegionTypeRateInline,
        CustomerRegionRateInline,
        CustomerDefaultRateInline,
    ]

admin.site.register(CustomerRatecard, CustomerRatecardAdmin)


class CustomerPrefixRateAdminForm(forms.ModelForm):

    class Meta:
        model = CustomerPrefixRate
        fields = '__all__'


class CustomerPrefixRateAdmin(admin.ModelAdmin):
    form = CustomerPrefixRateAdminForm
    list_display = ['prefix', 'destnum_length', 'r_rate', 'status',]
    # readonly_fields = ['prefix', 'destnum_length']

admin.site.register(CustomerPrefixRate, CustomerPrefixRateAdmin)


class ProviderPrefixRateAdminForm(forms.ModelForm):

    class Meta:
        model = ProviderPrefixRate
        fields = '__all__'


class ProviderPrefixRateAdmin(admin.ModelAdmin):
    form = ProviderPrefixRateAdminForm
    list_display = ['prefix', 'destnum_length', 'r_rate', 'status',]
    # readonly_fields = ['prefix', 'destnum_length']

admin.site.register(ProviderPrefixRate, ProviderPrefixRateAdmin)


class CustomerDestinationRateAdminForm(forms.ModelForm):

    class Meta:
        model = CustomerDestinationRate
        fields = '__all__'


class CustomerDestinationRateAdmin(admin.ModelAdmin):
    form = CustomerDestinationRateAdminForm


admin.site.register(CustomerDestinationRate, CustomerDestinationRateAdmin)


class ProviderDestinationRateAdminForm(forms.ModelForm):

    class Meta:
        model = ProviderDestinationRate
        fields = '__all__'


class ProviderDestinationRateAdmin(admin.ModelAdmin):
    form = ProviderDestinationRateAdminForm


admin.site.register(ProviderDestinationRate, ProviderDestinationRateAdmin)


class CustomerCountryTypeRateAdminForm(forms.ModelForm):

    class Meta:
        model = CustomerCountryTypeRate
        fields = '__all__'


class CustomerCountryTypeRateAdmin(admin.ModelAdmin):
    form = CustomerCountryTypeRateAdminForm


admin.site.register(CustomerCountryTypeRate, CustomerCountryTypeRateAdmin)


class ProviderCountryTypeRateAdminForm(forms.ModelForm):

    class Meta:
        model = ProviderCountryTypeRate
        fields = '__all__'


class ProviderCountryTypeRateAdmin(admin.ModelAdmin):
    form = ProviderCountryTypeRateAdminForm


admin.site.register(ProviderCountryTypeRate, ProviderCountryTypeRateAdmin)


class CustomerCountryRateAdminForm(forms.ModelForm):

    class Meta:
        model = CustomerCountryRate
        fields = '__all__'


class CustomerCountryRateAdmin(admin.ModelAdmin):
    form = CustomerCountryRateAdminForm


admin.site.register(CustomerCountryRate, CustomerCountryRateAdmin)


class ProviderCountryRateAdminForm(forms.ModelForm):

    class Meta:
        model = ProviderCountryRate
        fields = '__all__'


class ProviderCountryRateAdmin(admin.ModelAdmin):
    form = ProviderCountryRateAdminForm


admin.site.register(ProviderCountryRate, ProviderCountryRateAdmin)


class CustomerRegionTypeRateAdminForm(forms.ModelForm):

    class Meta:
        model = CustomerRegionTypeRate
        fields = '__all__'


class CustomerRegionTypeRateAdmin(admin.ModelAdmin):
    form = CustomerRegionTypeRateAdminForm


admin.site.register(CustomerRegionTypeRate, CustomerRegionTypeRateAdmin)


class ProviderRegionTypeRateAdminForm(forms.ModelForm):

    class Meta:
        model = ProviderRegionTypeRate
        fields = '__all__'


class ProviderRegionTypeRateAdmin(admin.ModelAdmin):
    form = ProviderRegionTypeRateAdminForm


admin.site.register(ProviderRegionTypeRate, ProviderRegionTypeRateAdmin)


class CustomerRegionRateAdminForm(forms.ModelForm):

    class Meta:
        model = CustomerRegionRate
        fields = '__all__'


class CustomerRegionRateAdmin(admin.ModelAdmin):
    form = CustomerRegionRateAdminForm


admin.site.register(CustomerRegionRate, CustomerRegionRateAdmin)


class ProviderRegionRateAdminForm(forms.ModelForm):

    class Meta:
        model = ProviderRegionRate
        fields = '__all__'


class ProviderRegionRateAdmin(admin.ModelAdmin):
    form = ProviderRegionRateAdminForm


admin.site.register(ProviderRegionRate, ProviderRegionRateAdmin)


class CustomerDefaultRateAdminForm(forms.ModelForm):

    class Meta:
        model = CustomerDefaultRate
        fields = '__all__'


class CustomerDefaultRateAdmin(admin.ModelAdmin):
    form = CustomerDefaultRateAdminForm


admin.site.register(CustomerDefaultRate, CustomerDefaultRateAdmin)


class ProviderDefaultRateAdminForm(forms.ModelForm):

    class Meta:
        model = ProviderDefaultRate
        fields = '__all__'


class ProviderDefaultRateAdmin(admin.ModelAdmin):
    form = ProviderDefaultRateAdminForm


admin.site.register(ProviderDefaultRate, ProviderDefaultRateAdmin)



from . import models

from rest_framework import serializers


class CallerNumListSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.CallerNumList
        fields = (
            'slug',
            'name',
            'callerid_filter',
        )


class ProviderRatecardSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.ProviderRatecard
        fields = (
            'slug',
            'name',
            'rc_type',
            'provider_prefix',
            'description',
            'date_start',
            'date_end',
            'estimated_quality',
            'status',
            'status_changed',
            'created',
            'modified',
        )


class CustomerRatecardSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.CustomerRatecard
        fields = (
            'slug',
            'rc_type',
            'name',
            'description',
            'date_start',
            'date_end',
            'status',
            'status_changed',
            'created',
            'modified',
        )


class CustomerPrefixRateSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.CustomerPrefixRate
        fields = (
            'pk',
            'prefix',
            'destnum_length',
            'r_rate',
            'r_block_min_duration',
            'r_minimal_time',
            'r_init_block',
            'status',
            'date_validity',
        )


class ProviderPrefixRateSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.ProviderPrefixRate
        fields = (
            'pk',
            'prefix',
            'destnum_length',
            'r_rate',
            'r_block_min_duration',
            'r_minimal_time',
            'r_init_block',
            'status',
        )


class CustomerDestinationRateSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.CustomerDestinationRate
        fields = (
            'pk',
            'r_rate',
            'r_block_min_duration',
            'r_minimal_time',
            'r_init_block',
            'status',
        )


class ProviderDestinationRateSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.ProviderDestinationRate
        fields = (
            'pk',
            'r_rate',
            'r_block_min_duration',
            'r_minimal_time',
            'r_init_block',
            'status',
        )


class CustomerCountryTypeRateSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.CustomerCountryTypeRate
        fields = (
            'pk',
            'r_rate',
            'r_block_min_duration',
            'r_minimal_time',
            'r_init_block',
            'status',
        )


class ProviderCountryTypeRateSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.ProviderCountryTypeRate
        fields = (
            'pk',
            'r_rate',
            'r_block_min_duration',
            'r_minimal_time',
            'r_init_block',
            'status',
        )


class CustomerCountryRateSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.CustomerCountryRate
        fields = (
            'pk',
            'r_rate',
            'r_block_min_duration',
            'r_minimal_time',
            'r_init_block',
            'status',
        )


class ProviderCountryRateSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.ProviderCountryRate
        fields = (
            'pk',
            'r_rate',
            'r_block_min_duration',
            'r_minimal_time',
            'r_init_block',
            'status',
        )


class CustomerRegionTypeRateSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.CustomerRegionTypeRate
        fields = (
            'pk',
            'r_rate',
            'r_block_min_duration',
            'r_minimal_time',
            'r_init_block',
            'status',
        )


class ProviderRegionTypeRateSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.ProviderRegionTypeRate
        fields = (
            'pk',
            'r_rate',
            'r_block_min_duration',
            'r_minimal_time',
            'r_init_block',
            'status',
        )


class CustomerRegionRateSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.CustomerRegionRate
        fields = (
            'pk',
            'r_rate',
            'r_block_min_duration',
            'r_minimal_time',
            'r_init_block',
            'status',
        )


class ProviderRegionRateSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.ProviderRegionRate
        fields = (
            'pk',
            'r_rate',
            'r_block_min_duration',
            'r_minimal_time',
            'r_init_block',
            'status',
        )


class CustomerDefaultRateSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.CustomerDefaultRate
        fields = (
            'pk',
            'r_rate',
            'r_block_min_duration',
            'r_minimal_time',
            'r_init_block',
            'status',
        )


class ProviderDefaultRateSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.ProviderDefaultRate
        fields = (
            'pk',
            'r_rate',
            'r_block_min_duration',
            'r_minimal_time',
            'r_init_block',
            'status',
        )



# -*- coding: utf-8 -*-
from django.urls import path, include
from rest_framework import routers

from . import api
from . import views


app_name = 'pyfb_rating'

router = routers.DefaultRouter()
router.register(r'callernumlist', api.CallerNumListViewSet)
router.register(r'providerratecard', api.ProviderRatecardViewSet)
router.register(r'customerratecard', api.CustomerRatecardViewSet)
router.register(r'customerprefixrate', api.CustomerPrefixRateViewSet)
router.register(r'providerprefixrate', api.ProviderPrefixRateViewSet)
router.register(r'customerdestinationrate', api.CustomerDestinationRateViewSet)
router.register(r'providerdestinationrate', api.ProviderDestinationRateViewSet)
router.register(r'customercountrytyperate', api.CustomerCountryTypeRateViewSet)
router.register(r'providercountrytyperate', api.ProviderCountryTypeRateViewSet)
router.register(r'customercountryrate', api.CustomerCountryRateViewSet)
router.register(r'providercountryrate', api.ProviderCountryRateViewSet)
router.register(r'customerregiontyperate', api.CustomerRegionTypeRateViewSet)
router.register(r'providerregiontyperate', api.ProviderRegionTypeRateViewSet)
router.register(r'customerregionrate', api.CustomerRegionRateViewSet)
router.register(r'providerregionrate', api.ProviderRegionRateViewSet)
router.register(r'customerdefaultrate', api.CustomerDefaultRateViewSet)
router.register(r'providerdefaultrate', api.ProviderDefaultRateViewSet)


urlpatterns = (
    # urls for Django Rest Framework API
    path('api/v1/', include(router.urls)),
)

urlpatterns += (
    # urls for CallerNumList
    path('rate/callernumlist/', views.CallerNumListListView.as_view(), name='pyfb_rating_callernumlist_list'),
    path('rate/callernumlist/create/', views.CallerNumListCreateView.as_view(), name='pyfb_rating_callernumlist_create'),
    path('rate/callernumlist/detail/<slug:slug>/', views.CallerNumListDetailView.as_view(), name='pyfb_rating_callernumlist_detail'),
    path('rate/callernumlist/update/<slug:slug>/', views.CallerNumListUpdateView.as_view(), name='pyfb_rating_callernumlist_update'),
)

urlpatterns += (
    # urls for ProviderRatecard
    path('rate/providerratecard/', views.ProviderRatecardListView.as_view(), name='pyfb_rating_providerratecard_list'),
    path('rate/providerratecard/create/', views.ProviderRatecardCreateView.as_view(), name='pyfb_rating_providerratecard_create'),
    path('rate/providerratecard/detail/<slug:slug>/', views.ProviderRatecardDetailView.as_view(), name='pyfb_rating_providerratecard_detail'),
    path('rate/providerratecard/update/<slug:slug>/', views.ProviderRatecardUpdateView.as_view(), name='pyfb_rating_providerratecard_update'),
)

urlpatterns += (
    # urls for CustomerRatecard
    path('rate/customerratecard/', views.CustomerRatecardListView.as_view(), name='pyfb_rating_customerratecard_list'),
    path('rate/customerratecard/create/', views.CustomerRatecardCreateView.as_view(), name='pyfb_rating_customerratecard_create'),
    path('rate/customerratecard/detail/<slug:slug>/', views.CustomerRatecardDetailView.as_view(), name='pyfb_rating_customerratecard_detail'),
    path('rate/customerratecard/update/<slug:slug>/', views.CustomerRatecardUpdateView.as_view(), name='pyfb_rating_customerratecard_update'),
)

urlpatterns += (
    # urls for CustomerPrefixRate
    path('rate/customerprefixrate/', views.CustomerPrefixRateListView.as_view(), name='pyfb_rating_customerprefixrate_list'),
    path('rate/customerprefixrate/create/', views.CustomerPrefixRateCreateView.as_view(), name='pyfb_rating_customerprefixrate_create'),
    path('rate/customerprefixrate/detail/<int:pk>/', views.CustomerPrefixRateDetailView.as_view(), name='pyfb_rating_customerprefixrate_detail'),
    path('rate/customerprefixrate/update/<int:pk>/', views.CustomerPrefixRateUpdateView.as_view(), name='pyfb_rating_customerprefixrate_update'),
)

urlpatterns += (
    # urls for ProviderPrefixRate
    path('rate/providerprefixrate/', views.ProviderPrefixRateListView.as_view(), name='pyfb_rating_providerprefixrate_list'),
    path('rate/providerprefixrate/create/', views.ProviderPrefixRateCreateView.as_view(), name='pyfb_rating_providerprefixrate_create'),
    path('rate/providerprefixrate/detail/<int:pk>/', views.ProviderPrefixRateDetailView.as_view(), name='pyfb_rating_providerprefixrate_detail'),
    path('rate/providerprefixrate/update/<int:pk>/', views.ProviderPrefixRateUpdateView.as_view(), name='pyfb_rating_providerprefixrate_update'),
)

urlpatterns += (
    # urls for CustomerDestinationRate
    path('rate/customerdestinationrate/', views.CustomerDestinationRateListView.as_view(), name='pyfb_rating_customerdestinationrate_list'),
    path('rate/customerdestinationrate/create/', views.CustomerDestinationRateCreateView.as_view(), name='pyfb_rating_customerdestinationrate_create'),
    path('rate/customerdestinationrate/detail/<int:pk>/', views.CustomerDestinationRateDetailView.as_view(), name='pyfb_rating_customerdestinationrate_detail'),
    path('rate/customerdestinationrate/update/<int:pk>/', views.CustomerDestinationRateUpdateView.as_view(), name='pyfb_rating_customerdestinationrate_update'),
)

urlpatterns += (
    # urls for ProviderDestinationRate
    path('rate/providerdestinationrate/', views.ProviderDestinationRateListView.as_view(), name='pyfb_rating_providerdestinationrate_list'),
    path('rate/providerdestinationrate/create/', views.ProviderDestinationRateCreateView.as_view(), name='pyfb_rating_providerdestinationrate_create'),
    path('rate/providerdestinationrate/detail/<int:pk>/', views.ProviderDestinationRateDetailView.as_view(), name='pyfb_rating_providerdestinationrate_detail'),
    path('rate/providerdestinationrate/update/<int:pk>/', views.ProviderDestinationRateUpdateView.as_view(), name='pyfb_rating_providerdestinationrate_update'),
)

urlpatterns += (
    # urls for CustomerCountryTypeRate
    path('rate/customercountrytyperate/', views.CustomerCountryTypeRateListView.as_view(), name='pyfb_rating_customercountrytyperate_list'),
    path('rate/customercountrytyperate/create/', views.CustomerCountryTypeRateCreateView.as_view(), name='pyfb_rating_customercountrytyperate_create'),
    path('rate/customercountrytyperate/detail/<int:pk>/', views.CustomerCountryTypeRateDetailView.as_view(), name='pyfb_rating_customercountrytyperate_detail'),
    path('rate/customercountrytyperate/update/<int:pk>/', views.CustomerCountryTypeRateUpdateView.as_view(), name='pyfb_rating_customercountrytyperate_update'),
)

urlpatterns += (
    # urls for ProviderCountryTypeRate
    path('rate/providercountrytyperate/', views.ProviderCountryTypeRateListView.as_view(), name='pyfb_rating_providercountrytyperate_list'),
    path('rate/providercountrytyperate/create/', views.ProviderCountryTypeRateCreateView.as_view(), name='pyfb_rating_providercountrytyperate_create'),
    path('rate/providercountrytyperate/detail/<int:pk>/', views.ProviderCountryTypeRateDetailView.as_view(), name='pyfb_rating_providercountrytyperate_detail'),
    path('rate/providercountrytyperate/update/<int:pk>/', views.ProviderCountryTypeRateUpdateView.as_view(), name='pyfb_rating_providercountrytyperate_update'),
)

urlpatterns += (
    # urls for CustomerCountryRate
    path('rate/customercountryrate/', views.CustomerCountryRateListView.as_view(), name='pyfb_rating_customercountryrate_list'),
    path('rate/customercountryrate/create/', views.CustomerCountryRateCreateView.as_view(), name='pyfb_rating_customercountryrate_create'),
    path('rate/customercountryrate/detail/<int:pk>/', views.CustomerCountryRateDetailView.as_view(), name='pyfb_rating_customercountryrate_detail'),
    path('rate/customercountryrate/update/<int:pk>/', views.CustomerCountryRateUpdateView.as_view(), name='pyfb_rating_customercountryrate_update'),
)

urlpatterns += (
    # urls for ProviderCountryRate
    path('rate/providercountryrate/', views.ProviderCountryRateListView.as_view(), name='pyfb_rating_providercountryrate_list'),
    path('rate/providercountryrate/create/', views.ProviderCountryRateCreateView.as_view(), name='pyfb_rating_providercountryrate_create'),
    path('rate/providercountryrate/detail/<int:pk>/', views.ProviderCountryRateDetailView.as_view(), name='pyfb_rating_providercountryrate_detail'),
    path('rate/providercountryrate/update/<int:pk>/', views.ProviderCountryRateUpdateView.as_view(), name='pyfb_rating_providercountryrate_update'),
)

urlpatterns += (
    # urls for CustomerRegionTypeRate
    path('rate/customerregiontyperate/', views.CustomerRegionTypeRateListView.as_view(), name='pyfb_rating_customerregiontyperate_list'),
    path('rate/customerregiontyperate/create/', views.CustomerRegionTypeRateCreateView.as_view(), name='pyfb_rating_customerregiontyperate_create'),
    path('rate/customerregiontyperate/detail/<int:pk>/', views.CustomerRegionTypeRateDetailView.as_view(), name='pyfb_rating_customerregiontyperate_detail'),
    path('rate/customerregiontyperate/update/<int:pk>/', views.CustomerRegionTypeRateUpdateView.as_view(), name='pyfb_rating_customerregiontyperate_update'),
)

urlpatterns += (
    # urls for ProviderRegionTypeRate
    path('rate/providerregiontyperate/', views.ProviderRegionTypeRateListView.as_view(), name='pyfb_rating_providerregiontyperate_list'),
    path('rate/providerregiontyperate/create/', views.ProviderRegionTypeRateCreateView.as_view(), name='pyfb_rating_providerregiontyperate_create'),
    path('rate/providerregiontyperate/detail/<int:pk>/', views.ProviderRegionTypeRateDetailView.as_view(), name='pyfb_rating_providerregiontyperate_detail'),
    path('rate/providerregiontyperate/update/<int:pk>/', views.ProviderRegionTypeRateUpdateView.as_view(), name='pyfb_rating_providerregiontyperate_update'),
)

urlpatterns += (
    # urls for CustomerRegionRate
    path('rate/customerregionrate/', views.CustomerRegionRateListView.as_view(), name='pyfb_rating_customerregionrate_list'),
    path('rate/customerregionrate/create/', views.CustomerRegionRateCreateView.as_view(), name='pyfb_rating_customerregionrate_create'),
    path('rate/customerregionrate/detail/<int:pk>/', views.CustomerRegionRateDetailView.as_view(), name='pyfb_rating_customerregionrate_detail'),
    path('rate/customerregionrate/update/<int:pk>/', views.CustomerRegionRateUpdateView.as_view(), name='pyfb_rating_customerregionrate_update'),
)

urlpatterns += (
    # urls for ProviderRegionRate
    path('rate/providerregionrate/', views.ProviderRegionRateListView.as_view(), name='pyfb_rating_providerregionrate_list'),
    path('rate/providerregionrate/create/', views.ProviderRegionRateCreateView.as_view(), name='pyfb_rating_providerregionrate_create'),
    path('rate/providerregionrate/detail/<int:pk>/', views.ProviderRegionRateDetailView.as_view(), name='pyfb_rating_providerregionrate_detail'),
    path('rate/providerregionrate/update/<int:pk>/', views.ProviderRegionRateUpdateView.as_view(), name='pyfb_rating_providerregionrate_update'),
)

urlpatterns += (
    # urls for CustomerDefaultRate
    path('rate/customerdefaultrate/', views.CustomerDefaultRateListView.as_view(), name='pyfb_rating_customerdefaultrate_list'),
    path('rate/customerdefaultrate/create/', views.CustomerDefaultRateCreateView.as_view(), name='pyfb_rating_customerdefaultrate_create'),
    path('rate/customerdefaultrate/detail/<int:pk>/', views.CustomerDefaultRateDetailView.as_view(), name='pyfb_rating_customerdefaultrate_detail'),
    path('rate/customerdefaultrate/update/<int:pk>/', views.CustomerDefaultRateUpdateView.as_view(), name='pyfb_rating_customerdefaultrate_update'),
)

urlpatterns += (
    # urls for ProviderDefaultRate
    path('rate/providerdefaultrate/', views.ProviderDefaultRateListView.as_view(), name='pyfb_rating_providerdefaultrate_list'),
    path('rate/providerdefaultrate/create/', views.ProviderDefaultRateCreateView.as_view(), name='pyfb_rating_providerdefaultrate_create'),
    path('rate/providerdefaultrate/detail/<int:pk>/', views.ProviderDefaultRateDetailView.as_view(), name='pyfb_rating_providerdefaultrate_detail'),
    path('rate/providerdefaultrate/update/<int:pk>/', views.ProviderDefaultRateUpdateView.as_view(), name='pyfb_rating_providerdefaultrate_update'),
)



from . import models
from . import serializers
from rest_framework import viewsets, permissions


class CallerNumListViewSet(viewsets.ModelViewSet):
    """ViewSet for the CallerNumList class"""

    queryset = models.CallerNumList.objects.all()
    serializer_class = serializers.CallerNumListSerializer
    permission_classes = [permissions.IsAuthenticated]


class ProviderRatecardViewSet(viewsets.ModelViewSet):
    """ViewSet for the ProviderRatecard class"""

    queryset = models.ProviderRatecard.objects.all()
    serializer_class = serializers.ProviderRatecardSerializer
    permission_classes = [permissions.IsAuthenticated]


class CustomerRatecardViewSet(viewsets.ModelViewSet):
    """ViewSet for the CustomerRatecard class"""

    queryset = models.CustomerRatecard.objects.all()
    serializer_class = serializers.CustomerRatecardSerializer
    permission_classes = [permissions.IsAuthenticated]


class CustomerPrefixRateViewSet(viewsets.ModelViewSet):
    """ViewSet for the CustomerPrefixRate class"""

    queryset = models.CustomerPrefixRate.objects.all()
    serializer_class = serializers.CustomerPrefixRateSerializer
    permission_classes = [permissions.IsAuthenticated]


class ProviderPrefixRateViewSet(viewsets.ModelViewSet):
    """ViewSet for the ProviderPrefixRate class"""

    queryset = models.ProviderPrefixRate.objects.all()
    serializer_class = serializers.ProviderPrefixRateSerializer
    permission_classes = [permissions.IsAuthenticated]


class CustomerDestinationRateViewSet(viewsets.ModelViewSet):
    """ViewSet for the CustomerDestinationRate class"""

    queryset = models.CustomerDestinationRate.objects.all()
    serializer_class = serializers.CustomerDestinationRateSerializer
    permission_classes = [permissions.IsAuthenticated]


class ProviderDestinationRateViewSet(viewsets.ModelViewSet):
    """ViewSet for the ProviderDestinationRate class"""

    queryset = models.ProviderDestinationRate.objects.all()
    serializer_class = serializers.ProviderDestinationRateSerializer
    permission_classes = [permissions.IsAuthenticated]


class CustomerCountryTypeRateViewSet(viewsets.ModelViewSet):
    """ViewSet for the CustomerCountryTypeRate class"""

    queryset = models.CustomerCountryTypeRate.objects.all()
    serializer_class = serializers.CustomerCountryTypeRateSerializer
    permission_classes = [permissions.IsAuthenticated]


class ProviderCountryTypeRateViewSet(viewsets.ModelViewSet):
    """ViewSet for the ProviderCountryTypeRate class"""

    queryset = models.ProviderCountryTypeRate.objects.all()
    serializer_class = serializers.ProviderCountryTypeRateSerializer
    permission_classes = [permissions.IsAuthenticated]


class CustomerCountryRateViewSet(viewsets.ModelViewSet):
    """ViewSet for the CustomerCountryRate class"""

    queryset = models.CustomerCountryRate.objects.all()
    serializer_class = serializers.CustomerCountryRateSerializer
    permission_classes = [permissions.IsAuthenticated]


class ProviderCountryRateViewSet(viewsets.ModelViewSet):
    """ViewSet for the ProviderCountryRate class"""

    queryset = models.ProviderCountryRate.objects.all()
    serializer_class = serializers.ProviderCountryRateSerializer
    permission_classes = [permissions.IsAuthenticated]


class CustomerRegionTypeRateViewSet(viewsets.ModelViewSet):
    """ViewSet for the CustomerRegionTypeRate class"""

    queryset = models.CustomerRegionTypeRate.objects.all()
    serializer_class = serializers.CustomerRegionTypeRateSerializer
    permission_classes = [permissions.IsAuthenticated]


class ProviderRegionTypeRateViewSet(viewsets.ModelViewSet):
    """ViewSet for the ProviderRegionTypeRate class"""

    queryset = models.ProviderRegionTypeRate.objects.all()
    serializer_class = serializers.ProviderRegionTypeRateSerializer
    permission_classes = [permissions.IsAuthenticated]


class CustomerRegionRateViewSet(viewsets.ModelViewSet):
    """ViewSet for the CustomerRegionRate class"""

    queryset = models.CustomerRegionRate.objects.all()
    serializer_class = serializers.CustomerRegionRateSerializer
    permission_classes = [permissions.IsAuthenticated]


class ProviderRegionRateViewSet(viewsets.ModelViewSet):
    """ViewSet for the ProviderRegionRate class"""

    queryset = models.ProviderRegionRate.objects.all()
    serializer_class = serializers.ProviderRegionRateSerializer
    permission_classes = [permissions.IsAuthenticated]


class CustomerDefaultRateViewSet(viewsets.ModelViewSet):
    """ViewSet for the CustomerDefaultRate class"""

    queryset = models.CustomerDefaultRate.objects.all()
    serializer_class = serializers.CustomerDefaultRateSerializer
    permission_classes = [permissions.IsAuthenticated]


class ProviderDefaultRateViewSet(viewsets.ModelViewSet):
    """ViewSet for the ProviderDefaultRate class"""

    queryset = models.ProviderDefaultRate.objects.all()
    serializer_class = serializers.ProviderDefaultRateSerializer
    permission_classes = [permissions.IsAuthenticated]



from django import forms
from .models import CallerNumList, ProviderRatecard, CustomerRatecard, CustomerPrefixRate, ProviderPrefixRate, CustomerDestinationRate, ProviderDestinationRate, CustomerCountryTypeRate, ProviderCountryTypeRate, CustomerCountryRate, ProviderCountryRate, CustomerRegionTypeRate, ProviderRegionTypeRate, CustomerRegionRate, ProviderRegionRate, CustomerDefaultRate, ProviderDefaultRate


class CallerNumListForm(forms.ModelForm):
    class Meta:
        model = CallerNumList
        fields = ['name', 'callerid_filter', 'destination']


class ProviderRatecardForm(forms.ModelForm):
    class Meta:
        model = ProviderRatecard
        fields = ['name', 'rc_type', 'provider_prefix', 'estimated_quality', 'date_start', 'date_end', 'status', 'status_changed']


class CustomerRatecardForm(forms.ModelForm):
    class Meta:
        model = CustomerRatecard
        fields = ['rc_type', 'name', 'status', 'status_changed']


class CustomerPrefixRateForm(forms.ModelForm):
    class Meta:
        model = CustomerPrefixRate
        fields = ['prefix', 'destnum_length', 'c_ratecard', 'r_rate', 'status']


class ProviderPrefixRateForm(forms.ModelForm):
    class Meta:
        model = ProviderPrefixRate
        fields = ['prefix', 'destnum_length', 'p_ratecard', 'r_rate', 'status']


class CustomerDestinationRateForm(forms.ModelForm):
    class Meta:
        model = CustomerDestinationRate
        fields = ['c_ratecard', 'destination', 'r_rate', 'status']


class ProviderDestinationRateForm(forms.ModelForm):
    class Meta:
        model = ProviderDestinationRate
        fields = ['p_ratecard', 'destination', 'r_rate', 'status']


class CustomerCountryTypeRateForm(forms.ModelForm):
    class Meta:
        model = CustomerCountryTypeRate
        fields = ['c_ratecard', 'country', 'type', 'r_rate', 'status']


class ProviderCountryTypeRateForm(forms.ModelForm):
    class Meta:
        model = ProviderCountryTypeRate
        fields = ['p_ratecard', 'country', 'type', 'r_rate', 'status']


class CustomerCountryRateForm(forms.ModelForm):
    class Meta:
        model = CustomerCountryRate
        fields = ['c_ratecard', 'country', 'r_rate', 'status']


class ProviderCountryRateForm(forms.ModelForm):
    class Meta:
        model = ProviderCountryRate
        fields = ['p_ratecard', 'country', 'r_rate', 'status']


class CustomerRegionTypeRateForm(forms.ModelForm):
    class Meta:
        model = CustomerRegionTypeRate
        fields = ['c_ratecard', 'region', 'type', 'r_rate', 'status']


class ProviderRegionTypeRateForm(forms.ModelForm):
    class Meta:
        model = ProviderRegionTypeRate
        fields = ['p_ratecard', 'region', 'type', 'r_rate', 'status']


class CustomerRegionRateForm(forms.ModelForm):
    class Meta:
        model = CustomerRegionRate
        fields = ['c_ratecard', 'region', 'r_rate', 'status']


class ProviderRegionRateForm(forms.ModelForm):
    class Meta:
        model = ProviderRegionRate
        fields = ['p_ratecard', 'region', 'r_rate', 'status']


class CustomerDefaultRateForm(forms.ModelForm):
    class Meta:
        model = CustomerDefaultRate
        fields = ['c_ratecard', 'r_rate', 'status']


class ProviderDefaultRateForm(forms.ModelForm):
    class Meta:
        model = ProviderDefaultRate
        fields = ['p_ratecard', 'r_rate', 'status']



# Generated by Django 2.1.4 on 2018-12-07 15:17

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_rating', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customerratecard',
            name='callerid_list',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='pyfb_rating.CallerNumList'),
        ),
        migrations.AlterField(
            model_name='providerratecard',
            name='callerid_list',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='pyfb_rating.CallerNumList'),
        ),
        migrations.AlterField(
            model_name='providerratecard',
            name='provider_prefix',
            field=models.CharField(blank=True, default='', max_length=10, verbose_name='tech prefix'),
        ),
    ]



# -*- coding: utf-8 -*-
from django.views.generic import DetailView, ListView, UpdateView, CreateView
from .models import CallerNumList, ProviderRatecard, CustomerRatecard, CustomerPrefixRate, ProviderPrefixRate, CustomerDestinationRate, ProviderDestinationRate, CustomerCountryTypeRate, ProviderCountryTypeRate, CustomerCountryRate, ProviderCountryRate, CustomerRegionTypeRate, ProviderRegionTypeRate, CustomerRegionRate, ProviderRegionRate, CustomerDefaultRate, ProviderDefaultRate
from .forms import CallerNumListForm, ProviderRatecardForm, CustomerRatecardForm, CustomerPrefixRateForm, ProviderPrefixRateForm, CustomerDestinationRateForm, ProviderDestinationRateForm, CustomerCountryTypeRateForm, ProviderCountryTypeRateForm, CustomerCountryRateForm, ProviderCountryRateForm, CustomerRegionTypeRateForm, ProviderRegionTypeRateForm, CustomerRegionRateForm, ProviderRegionRateForm, CustomerDefaultRateForm, ProviderDefaultRateForm


class CallerNumListListView(ListView):
    model = CallerNumList


class CallerNumListCreateView(CreateView):
    model = CallerNumList
    form_class = CallerNumListForm


class CallerNumListDetailView(DetailView):
    model = CallerNumList


class CallerNumListUpdateView(UpdateView):
    model = CallerNumList
    form_class = CallerNumListForm


class ProviderRatecardListView(ListView):
    model = ProviderRatecard


class ProviderRatecardCreateView(CreateView):
    model = ProviderRatecard
    form_class = ProviderRatecardForm


class ProviderRatecardDetailView(DetailView):
    model = ProviderRatecard


class ProviderRatecardUpdateView(UpdateView):
    model = ProviderRatecard
    form_class = ProviderRatecardForm


class CustomerRatecardListView(ListView):
    model = CustomerRatecard


class CustomerRatecardCreateView(CreateView):
    model = CustomerRatecard
    form_class = CustomerRatecardForm


class CustomerRatecardDetailView(DetailView):
    model = CustomerRatecard


class CustomerRatecardUpdateView(UpdateView):
    model = CustomerRatecard
    form_class = CustomerRatecardForm


class CustomerPrefixRateListView(ListView):
    model = CustomerPrefixRate


class CustomerPrefixRateCreateView(CreateView):
    model = CustomerPrefixRate
    form_class = CustomerPrefixRateForm


class CustomerPrefixRateDetailView(DetailView):
    model = CustomerPrefixRate


class CustomerPrefixRateUpdateView(UpdateView):
    model = CustomerPrefixRate
    form_class = CustomerPrefixRateForm


class ProviderPrefixRateListView(ListView):
    model = ProviderPrefixRate


class ProviderPrefixRateCreateView(CreateView):
    model = ProviderPrefixRate
    form_class = ProviderPrefixRateForm


class ProviderPrefixRateDetailView(DetailView):
    model = ProviderPrefixRate


class ProviderPrefixRateUpdateView(UpdateView):
    model = ProviderPrefixRate
    form_class = ProviderPrefixRateForm


class CustomerDestinationRateListView(ListView):
    model = CustomerDestinationRate


class CustomerDestinationRateCreateView(CreateView):
    model = CustomerDestinationRate
    form_class = CustomerDestinationRateForm


class CustomerDestinationRateDetailView(DetailView):
    model = CustomerDestinationRate


class CustomerDestinationRateUpdateView(UpdateView):
    model = CustomerDestinationRate
    form_class = CustomerDestinationRateForm


class ProviderDestinationRateListView(ListView):
    model = ProviderDestinationRate


class ProviderDestinationRateCreateView(CreateView):
    model = ProviderDestinationRate
    form_class = ProviderDestinationRateForm


class ProviderDestinationRateDetailView(DetailView):
    model = ProviderDestinationRate


class ProviderDestinationRateUpdateView(UpdateView):
    model = ProviderDestinationRate
    form_class = ProviderDestinationRateForm


class CustomerCountryTypeRateListView(ListView):
    model = CustomerCountryTypeRate


class CustomerCountryTypeRateCreateView(CreateView):
    model = CustomerCountryTypeRate
    form_class = CustomerCountryTypeRateForm


class CustomerCountryTypeRateDetailView(DetailView):
    model = CustomerCountryTypeRate


class CustomerCountryTypeRateUpdateView(UpdateView):
    model = CustomerCountryTypeRate
    form_class = CustomerCountryTypeRateForm


class ProviderCountryTypeRateListView(ListView):
    model = ProviderCountryTypeRate


class ProviderCountryTypeRateCreateView(CreateView):
    model = ProviderCountryTypeRate
    form_class = ProviderCountryTypeRateForm


class ProviderCountryTypeRateDetailView(DetailView):
    model = ProviderCountryTypeRate


class ProviderCountryTypeRateUpdateView(UpdateView):
    model = ProviderCountryTypeRate
    form_class = ProviderCountryTypeRateForm


class CustomerCountryRateListView(ListView):
    model = CustomerCountryRate


class CustomerCountryRateCreateView(CreateView):
    model = CustomerCountryRate
    form_class = CustomerCountryRateForm


class CustomerCountryRateDetailView(DetailView):
    model = CustomerCountryRate


class CustomerCountryRateUpdateView(UpdateView):
    model = CustomerCountryRate
    form_class = CustomerCountryRateForm


class ProviderCountryRateListView(ListView):
    model = ProviderCountryRate


class ProviderCountryRateCreateView(CreateView):
    model = ProviderCountryRate
    form_class = ProviderCountryRateForm


class ProviderCountryRateDetailView(DetailView):
    model = ProviderCountryRate


class ProviderCountryRateUpdateView(UpdateView):
    model = ProviderCountryRate
    form_class = ProviderCountryRateForm


class CustomerRegionTypeRateListView(ListView):
    model = CustomerRegionTypeRate


class CustomerRegionTypeRateCreateView(CreateView):
    model = CustomerRegionTypeRate
    form_class = CustomerRegionTypeRateForm


class CustomerRegionTypeRateDetailView(DetailView):
    model = CustomerRegionTypeRate


class CustomerRegionTypeRateUpdateView(UpdateView):
    model = CustomerRegionTypeRate
    form_class = CustomerRegionTypeRateForm


class ProviderRegionTypeRateListView(ListView):
    model = ProviderRegionTypeRate


class ProviderRegionTypeRateCreateView(CreateView):
    model = ProviderRegionTypeRate
    form_class = ProviderRegionTypeRateForm


class ProviderRegionTypeRateDetailView(DetailView):
    model = ProviderRegionTypeRate


class ProviderRegionTypeRateUpdateView(UpdateView):
    model = ProviderRegionTypeRate
    form_class = ProviderRegionTypeRateForm


class CustomerRegionRateListView(ListView):
    model = CustomerRegionRate


class CustomerRegionRateCreateView(CreateView):
    model = CustomerRegionRate
    form_class = CustomerRegionRateForm


class CustomerRegionRateDetailView(DetailView):
    model = CustomerRegionRate


class CustomerRegionRateUpdateView(UpdateView):
    model = CustomerRegionRate
    form_class = CustomerRegionRateForm


class ProviderRegionRateListView(ListView):
    model = ProviderRegionRate


class ProviderRegionRateCreateView(CreateView):
    model = ProviderRegionRate
    form_class = ProviderRegionRateForm


class ProviderRegionRateDetailView(DetailView):
    model = ProviderRegionRate


class ProviderRegionRateUpdateView(UpdateView):
    model = ProviderRegionRate
    form_class = ProviderRegionRateForm


class CustomerDefaultRateListView(ListView):
    model = CustomerDefaultRate


class CustomerDefaultRateCreateView(CreateView):
    model = CustomerDefaultRate
    form_class = CustomerDefaultRateForm


class CustomerDefaultRateDetailView(DetailView):
    model = CustomerDefaultRate


class CustomerDefaultRateUpdateView(UpdateView):
    model = CustomerDefaultRate
    form_class = CustomerDefaultRateForm


class ProviderDefaultRateListView(ListView):
    model = ProviderDefaultRate


class ProviderDefaultRateCreateView(CreateView):
    model = ProviderDefaultRate
    form_class = ProviderDefaultRateForm


class ProviderDefaultRateDetailView(DetailView):
    model = ProviderDefaultRate


class ProviderDefaultRateUpdateView(UpdateView):
    model = ProviderDefaultRate
    form_class = ProviderDefaultRateForm



# -*- coding: utf-8 -*-

from django.core.validators import MaxValueValidator
from django.urls import reverse
from django.db import models as models
from django.db.models import *
from django.conf import settings
from django.contrib.postgres.fields import DateTimeRangeField
from django.utils import timezone
from django.utils.translation import ugettext_lazy as _

from django_extensions.db import fields as extension_fields
from django_extensions.db.fields import AutoSlugField

from model_utils.models import StatusModel, TimeStampedModel
from model_utils import Choices

from partial_index import PartialIndex

from pyfb_direction.models import Country, Destination, Region, Type


# Caller Number List management
class CallerNumList(TimeStampedModel):

    # Choices
    CALLERID_FILTER_CHOICES = (
        ('1', _(u"No filter")),
        ('2', _(u"Prefix authorized")),
        ('3', _(u"Prefix prohibited")),
    )

    # Fields
    name = models.CharField(max_length=128, unique=True)
    slug = extension_fields.AutoSlugField(populate_from='name', blank=True)
    callerid_filter = models.CharField(_(u"CallerID Prefix filter"), max_length=2, choices=CALLERID_FILTER_CHOICES, default='1')

    # Relationship Fields
    destination = models.ManyToManyField(Destination)

    class Meta:
        db_table = 'pyfb_rating_callernum_list'
        ordering = ('-name',)

    def __str__(self):
        return u'%s' % self.slug

    def __unicode__(self):
        return u'%s' % self.slug

    def get_absolute_url(self):
        return reverse('pyfb-rating:pyfb_rating_callernumlist_detail', args=(self.slug,))

    def get_update_url(self):
        return reverse('pyfb-rating:pyfb_rating_callernumlist_update', args=(self.slug,))


# Ratecard management
def default_time():
    return timezone.now() + timezone.timedelta(days=3650)


class RatecardModel(models.Model):

    # Fields
    description = models.TextField(_(u'description'), blank=True)
    # To be implemented later, for the time beiing, we will use two separated fields
    # date_validity = DateTimeRangeField()
    date_start = models.DateTimeField(default=timezone.now)
    date_end = models.DateTimeField(default=default_time)

    # Relationship Fields
    callerid_list = models.ForeignKey(CallerNumList,
        on_delete=models.PROTECT,
        null=True,
        blank=True,
    )

    class Meta:
        abstract = True


class CustomerRatecard(StatusModel, TimeStampedModel, RatecardModel):

    # choices
    RCTYPE_CHOICES = (
        ('pstn', _(u"Outbound calls")),
        ('did', _(u"DID - Inbound calls")),
        ('pstn2did', _(u"Outbound calls to internal DID")),
        ('emergency', _(u"Emergency calls"))
    )
    STATUS = Choices(
        ('enabled', _(u"Enabled")),
        ('disabled', _(u"Disabled")),
    )

    # Fields
    name = models.CharField(_(u'name'), max_length=128, unique=True)
    slug = extension_fields.AutoSlugField(populate_from='name', blank=True)
    rc_type = models.CharField(_(u"Type of ratecards"), max_length=10, choices=RCTYPE_CHOICES, default='pstn', help_text=_(u"Select the right ratecard regarding the type of calls. Default is PSTN"))

    class Meta:
        db_table = 'pyfb_rating_c_ratecard'
        ordering = ('name',)
        indexes = [
            PartialIndex(fields=['id', 'rc_type'], unique=False, where_postgresql='status = \'enabled\''),
            PartialIndex(fields=['id', 'rc_type'], unique=False, where='status = \'enabled\' AND rc_type = \'PSTN\''),
            PartialIndex(fields=['id', 'rc_type'], unique=False, where='status = \'enabled\' AND rc_type = \'DIDIN\''),
            PartialIndex(fields=['id', 'rc_type'], unique=False, where='status = \'enabled\' AND rc_type = \'DIDOUT\''),
            PartialIndex(fields=['id', 'rc_type'], unique=False, where='status = \'enabled\' AND rc_type = \'EMERGENCY\''),
        ]

    def __unicode__(self):
        return u'%s' % self.slug

    def __unicode__(self):
        return u'%s' % self.slug

    def get_absolute_url(self):
        return reverse('pyfb-rating:pyfb_rating_customerratecard_detail', args=(self.slug,))

    def get_update_url(self):
        return reverse('pyfb-rating:pyfb_rating_customerratecard_update', args=(self.slug,))


class ProviderRatecard(StatusModel, TimeStampedModel, RatecardModel):

    # choices
    RCTYPE_CHOICES = (
        ('pstn', _(u"Outbound calls")),
        ('did', _(u"DID - Inbound calls")),
        ('pstn2did', _(u"Outbound calls to internal DID")),
        ('emergency', _(u"Emergency calls"))
    )
    STATUS = Choices(
        ('enabled', _(u"Enabled")),
        ('disabled', _(u"Disabled")),
    )

    # Fields
    name = models.CharField(max_length=128, unique=True)
    slug = extension_fields.AutoSlugField(populate_from='name', blank=True)
    rc_type = models.CharField(_(u"Type of ratecards"), max_length=10, choices=RCTYPE_CHOICES, default='pstn', help_text=_(u"Select the right ratecard regarding the type of calls. Default is PSTN"))
    provider_prefix = models.CharField(_(u'tech prefix'), max_length=10, default='', blank=True)
    estimated_quality = models.PositiveSmallIntegerField(_(u'quality'), validators=[MaxValueValidator(10)], default='10', help_text=_(u"Estimated quality. Number between 0 to 10"))

    class Meta:
        db_table = 'pyfb_rating_p_ratecard'
        ordering = ('name',)
        indexes = [
            PartialIndex(fields=['id', 'rc_type'], unique=False, where_postgresql='status = \'enabled\''),
            PartialIndex(fields=['id', 'rc_type'], unique=False, where='status = \'enabled\' AND rc_type = \'PSTN\''),
            PartialIndex(fields=['id', 'rc_type'], unique=False, where='status = \'enabled\' AND rc_type = \'DIDIN\''),
            PartialIndex(fields=['id', 'rc_type'], unique=False, where='status = \'enabled\' AND rc_type = \'DIDOUT\''),
            PartialIndex(fields=['id', 'rc_type'], unique=False, where='status = \'enabled\' AND rc_type = \'EMERGENCY\''),
        ]

    def __unicode__(self):
        return u'%s' % self.slug

    def get_absolute_url(self):
        return reverse('pyfb-rating:pyfb_rating_providerratecard_detail', args=(self.slug,))

    def get_update_url(self):
        return reverse('pyfb-rating:pyfb_rating_providerratecard_update', args=(self.slug,))


# Rates management
class RateModel(models.Model):

    # choices
    STATUS_CHOICES = Choices(
        ('enabled', _(u"Enabled")),
        ('enabled_negmargin', _(u"Enabled allowing negative margin")),
        ('disabled', _(u"Disabled")),
        ('blocked', _(u"Blocked")),
    )

    # Fields
    r_rate = models.DecimalField(_(u'sell rate'), max_digits=11, decimal_places=5, help_text=_(u"rate per minute"))
    r_block_min_duration = models.PositiveSmallIntegerField(_(u'Increment'), default=1)
    r_minimal_time = models.PositiveSmallIntegerField(_(u'Minimal time'), default=0, help_text=_(u"minimal time to be billed in seconds"))
    r_init_block = models.DecimalField(_(u'Connection fee'), max_digits=11, decimal_places=5, default=0)
    status = models.CharField(_(u"Status"), max_length=20, default=STATUS_CHOICES.enabled, choices=STATUS_CHOICES, help_text=_(u"State of the rate : enabled / blocked - calls to this destination are blocked / disabled"))
    # To be implemented later, if someone needs this feature
    # date_validity = DateTimeRangeField()

    class Meta:
        abstract = True


class CustomerPrefixRate(TimeStampedModel, RateModel):

    # Fields
    prefix = models.CharField(_(u'numeric prefix'), max_length=30, db_index=True)
    destnum_length = models.PositiveSmallIntegerField(_(u'Destination number length'), default=0, help_text=_(u"If value > 0, then destination number must match tsi length"))

    # Relationship Fields
    c_ratecard = models.ForeignKey(CustomerRatecard, on_delete=models.CASCADE)

    class Meta:
        db_table = 'pyfb_rating_c_prefix_rate'
        ordering = ('c_ratecard',)
        unique_together = [
            ['c_ratecard', 'prefix', 'destnum_length'],
        ]
        indexes = [
            PartialIndex(
                fields=['c_ratecard', 'prefix', 'destnum_length'],
                unique=True,
                where='status <> \'disabled\''
            ),
        ]

    def __unicode__(self):
        return u'%s' % self.pk

    def get_absolute_url(self):
        return reverse('pyfb-rating:pyfb_rating_customerprefixrate_detail', args=(self.pk,))


    def get_update_url(self):
        return reverse('pyfb-rating:pyfb_rating_customerprefixrate_update', args=(self.pk,))


class ProviderPrefixRate(TimeStampedModel, RateModel):

    # Fields
    prefix = models.CharField(_(u'numeric prefix'), max_length=30, db_index=True)
    destnum_length = models.PositiveSmallIntegerField(_(u'Destination number length'), default=0, help_text=_(u"If value > 0, then destination number must match tsi length"))

    # Relationship Fields
    p_ratecard = models.ForeignKey(ProviderRatecard, on_delete=models.CASCADE)

    class Meta:
        db_table = 'pyfb_rating_p_prefix_rate'
        ordering = ('p_ratecard',)
        unique_together = [
            ['p_ratecard', 'prefix', 'destnum_length'],
        ]
        indexes = [
            PartialIndex(
                fields=['p_ratecard', 'prefix', 'destnum_length'],
                unique=True,
                where='status <> \'disabled\''
            ),
        ]

    def __unicode__(self):
        return u'%s' % self.pk

    def get_absolute_url(self):
        return reverse('pyfb-rating:pyfb_rating_providerprefixrate_detail', args=(self.pk,))


    def get_update_url(self):
        return reverse('pyfb-rating:pyfb_rating_providerprefixrate_update', args=(self.pk,))


class CustomerDestinationRate(TimeStampedModel, RateModel):


    # Relationship Fields
    c_ratecard = models.ForeignKey(CustomerRatecard, on_delete=models.CASCADE)
    destination = models.ForeignKey(Destination, on_delete=models.CASCADE)

    class Meta:
        db_table = 'pyfb_rating_c_destination_rate'
        ordering = ('c_ratecard',)
        unique_together = [
            ['c_ratecard', 'destination'],
        ]
        indexes = [
            PartialIndex(
                fields=['c_ratecard', 'destination'],
                unique=True,
                where='status <> \'disabled\''
            ),
        ]

    def __unicode__(self):
        return u'%s' % self.pk

    def get_absolute_url(self):
        return reverse('pyfb-rating:pyfb_rating_customerdestinationrate_detail', args=(self.pk,))


    def get_update_url(self):
        return reverse('pyfb-rating:pyfb_rating_customerdestinationrate_update', args=(self.pk,))


class ProviderDestinationRate(TimeStampedModel, RateModel):


    # Relationship Fields
    p_ratecard = models.ForeignKey(ProviderRatecard, on_delete=models.CASCADE)
    destination = models.ForeignKey(Destination, on_delete=models.CASCADE)

    class Meta:
        db_table = 'pyfb_rating_p_destination_rate'
        ordering = ('p_ratecard',)
        unique_together = [
            ['p_ratecard', 'destination'],
        ]
        indexes = [
            PartialIndex(
                fields=['p_ratecard', 'destination'],
                unique=True,
                where='status <> \'disabled\''
            ),
        ]

    def __unicode__(self):
        return u'%s' % self.pk

    def get_absolute_url(self):
        return reverse('pyfb-rating:pyfb_rating_providerdestinationrate_detail', args=(self.pk,))


    def get_update_url(self):
        return reverse('pyfb-rating:pyfb_rating_providerdestinationrate_update', args=(self.pk,))


class CustomerCountryTypeRate(TimeStampedModel, RateModel):


    # Relationship Fields
    c_ratecard = models.ForeignKey(CustomerRatecard, on_delete=models.CASCADE)
    country = models.ForeignKey(Country, on_delete=models.CASCADE)
    type = models.ForeignKey(Type, on_delete=models.CASCADE)

    class Meta:
        db_table = 'pyfb_rating_c_countrytype_rate'
        ordering = ('c_ratecard',)
        unique_together = [
            ['c_ratecard', 'country', 'type'],
        ]
        indexes = [
            PartialIndex(
                fields=['c_ratecard', 'country', 'type'],
                unique=True,
                where='status <> \'disabled\''
            ),
        ]

    def __unicode__(self):
        return u'%s' % self.pk

    def get_absolute_url(self):
        return reverse('pyfb-rating:pyfb_rating_customercountrytyperate_detail', args=(self.pk,))


    def get_update_url(self):
        return reverse('pyfb-rating:pyfb_rating_customercountrytyperate_update', args=(self.pk,))


class ProviderCountryTypeRate(TimeStampedModel, RateModel):


    # Relationship Fields
    p_ratecard = models.ForeignKey(ProviderRatecard, on_delete=models.CASCADE)
    country = models.ForeignKey(Country, on_delete=models.CASCADE)
    type = models.ForeignKey(Type, on_delete=models.CASCADE)

    class Meta:
        db_table = 'pyfb_rating_p_countrytype_rate'
        ordering = ('p_ratecard',)
        unique_together = [
            ['p_ratecard', 'country', 'type'],
        ]
        indexes = [
            PartialIndex(
                fields=['p_ratecard', 'country', 'type'],
                unique=True,
                where='status <> \'disabled\''
            ),
        ]

    def __unicode__(self):
        return u'%s' % self.pk

    def get_absolute_url(self):
        return reverse('pyfb-rating:pyfb_rating_providercountrytyperate_detail', args=(self.pk,))


    def get_update_url(self):
        return reverse('pyfb-rating:pyfb_rating_providercountrytyperate_update', args=(self.pk,))


class CustomerCountryRate(TimeStampedModel, RateModel):


    # Relationship Fields
    c_ratecard = models.ForeignKey(CustomerRatecard, on_delete=models.CASCADE)
    country = models.ForeignKey(Country, on_delete=models.CASCADE)

    class Meta:
        db_table = 'pyfb_rating_c_country_rate'
        ordering = ('c_ratecard',)
        unique_together = [
            ['c_ratecard', 'country'],
        ]
        indexes = [
            PartialIndex(
                fields=['c_ratecard', 'country'],
                unique=True,
                where='status <> \'disabled\''
            ),
        ]

    def __unicode__(self):
        return u'%s' % self.pk

    def get_absolute_url(self):
        return reverse('pyfb-rating:pyfb_rating_customercountryrate_detail', args=(self.pk,))


    def get_update_url(self):
        return reverse('pyfb-rating:pyfb_rating_customercountryrate_update', args=(self.pk,))


class ProviderCountryRate(TimeStampedModel, RateModel):


    # Relationship Fields
    p_ratecard = models.ForeignKey(ProviderRatecard, on_delete=models.CASCADE)
    country = models.ForeignKey(Country, on_delete=models.CASCADE)

    class Meta:
        db_table = 'pyfb_rating_p_country_rate'
        ordering = ('p_ratecard',)
        unique_together = [
            ['p_ratecard', 'country'],
        ]
        indexes = [
            PartialIndex(
                fields=['p_ratecard', 'country'],
                unique=True,
                where='status <> \'disabled\''
            ),
        ]

    def __unicode__(self):
        return u'%s' % self.pk

    def get_absolute_url(self):
        return reverse('pyfb-rating:pyfb_rating_providercountryrate_detail', args=(self.pk,))


    def get_update_url(self):
        return reverse('pyfb-rating:pyfb_rating_providercountryrate_update', args=(self.pk,))


class CustomerRegionTypeRate(TimeStampedModel, RateModel):


    # Relationship Fields
    c_ratecard = models.ForeignKey(CustomerRatecard, on_delete=models.CASCADE)
    region = models.ForeignKey(Region, on_delete=models.CASCADE)
    type = models.ForeignKey(Type, on_delete=models.CASCADE)

    class Meta:
        db_table = 'pyfb_rating_c_regiontype_rate'
        ordering = ('c_ratecard',)
        unique_together = [
            ['c_ratecard', 'region', 'type'],
        ]
        indexes = [
            PartialIndex(
                fields=['c_ratecard', 'region', 'type'],
                unique=True,
                where='status <> \'disabled\''
            ),
        ]

    def __unicode__(self):
        return u'%s' % self.pk

    def get_absolute_url(self):
        return reverse('pyfb-rating:pyfb_rating_customerregiontyperate_detail', args=(self.pk,))


    def get_update_url(self):
        return reverse('pyfb-rating:pyfb_rating_customerregiontyperate_update', args=(self.pk,))


class ProviderRegionTypeRate(TimeStampedModel, RateModel):


    # Relationship Fields
    p_ratecard = models.ForeignKey(ProviderRatecard, on_delete=models.CASCADE)
    region = models.ForeignKey(Region, on_delete=models.CASCADE)
    type = models.ForeignKey(Type, on_delete=models.CASCADE)

    class Meta:
        db_table = 'pyfb_rating_p_regiontype_rate'
        ordering = ('p_ratecard',)
        unique_together = [
            ['p_ratecard', 'region', 'type'],
        ]
        indexes = [
            PartialIndex(
                fields=['p_ratecard', 'region', 'type'],
                unique=True,
                where='status <> \'disabled\''
            ),
        ]

    def __unicode__(self):
        return u'%s' % self.pk

    def get_absolute_url(self):
        return reverse('pyfb-rating:pyfb_rating_providerregiontyperate_detail', args=(self.pk,))


    def get_update_url(self):
        return reverse('pyfb-rating:pyfb_rating_providerregiontyperate_update', args=(self.pk,))


class CustomerRegionRate(TimeStampedModel, RateModel):


    # Relationship Fields
    c_ratecard = models.ForeignKey(CustomerRatecard, on_delete=models.CASCADE)
    region = models.ForeignKey(Region, on_delete=models.CASCADE)

    class Meta:
        db_table = 'pyfb_rating_c_region_rate'
        ordering = ('c_ratecard',)
        unique_together = [
            ['c_ratecard', 'region'],
        ]
        indexes = [
            PartialIndex(
                fields=['c_ratecard', 'region'],
                unique=True,
                where='status <> \'disabled\''
            ),
        ]

    def __unicode__(self):
        return u'%s' % self.pk

    def get_absolute_url(self):
        return reverse('pyfb-rating:pyfb_rating_customerregionrate_detail', args=(self.pk,))


    def get_update_url(self):
        return reverse('pyfb-rating:pyfb_rating_customerregionrate_update', args=(self.pk,))


class ProviderRegionRate(TimeStampedModel, RateModel):


    # Relationship Fields
    p_ratecard = models.ForeignKey(ProviderRatecard, on_delete=models.CASCADE)
    region = models.ForeignKey(Region, on_delete=models.CASCADE)

    class Meta:
        db_table = 'pyfb_rating_p_region_rate'
        ordering = ('p_ratecard',)
        unique_together = [
            ['p_ratecard', 'region'],
        ]
        indexes = [
            PartialIndex(
                fields=['p_ratecard', 'region'],
                unique=True,
                where='status <> \'disabled\''
            ),
        ]

    def __unicode__(self):
        return u'%s' % self.pk

    def get_absolute_url(self):
        return reverse('pyfb-rating:pyfb_rating_providerregionrate_detail', args=(self.pk,))


    def get_update_url(self):
        return reverse('pyfb-rating:pyfb_rating_providerregionrate_update', args=(self.pk,))


class CustomerDefaultRate(TimeStampedModel, RateModel):


    # Relationship Fields
    c_ratecard = models.ForeignKey(CustomerRatecard, on_delete=models.CASCADE)

    class Meta:
        db_table = 'pyfb_rating_c_default_rate'
        ordering = ('c_ratecard',)
        indexes = [
            models.Index(fields=['c_ratecard']),
            PartialIndex(
                fields=['c_ratecard'],
                unique=True,
                where='status <> \'disabled\''
            ),
        ]

    def __unicode__(self):
        return u'%s' % self.pk

    def get_absolute_url(self):
        return reverse('pyfb-rating:pyfb_rating_customerdefaultrate_detail', args=(self.pk,))


    def get_update_url(self):
        return reverse('pyfb-rating:pyfb_rating_customerdefaultrate_update', args=(self.pk,))


class ProviderDefaultRate(TimeStampedModel, RateModel):


    # Relationship Fields
    p_ratecard = models.ForeignKey(ProviderRatecard, on_delete=models.CASCADE)

    class Meta:
        db_table = 'pyfb_rating_p_default_rate'
        ordering = ('p_ratecard',)
        indexes = [
            models.Index(fields=['p_ratecard']),
            PartialIndex(
                fields=['p_ratecard'],
                unique=True,
                where='status <> \'disabled\''
            ),
        ]

    def __unicode__(self):
        return u'%s' % self.pk

    def get_absolute_url(self):
        return reverse('pyfb-rating:pyfb_rating_providerdefaultrate_detail', args=(self.pk,))


    def get_update_url(self):
        return reverse('pyfb-rating:pyfb_rating_providerdefaultrate_update', args=(self.pk,))



# Generated by Django 2.1.4 on 2018-12-06 09:28

import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import django_extensions.db.fields
import model_utils.fields
import partial_index
import pyfb_rating.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('pyfb_direction', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='CallerNumList',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('name', models.CharField(max_length=128, unique=True)),
                ('slug', django_extensions.db.fields.AutoSlugField(blank=True, editable=False, populate_from='name')),
                ('callerid_filter', models.CharField(choices=[('1', 'No filter'), ('2', 'Prefix authorized'), ('3', 'Prefix prohibited')], default='1', max_length=2, verbose_name='CallerID Prefix filter')),
                ('destination', models.ManyToManyField(to='pyfb_direction.Destination')),
            ],
            options={
                'ordering': ('-name',),
                'db_table': 'pyfb_rating_callernum_list',
            },
        ),
        migrations.CreateModel(
            name='CustomerCountryRate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('r_rate', models.DecimalField(decimal_places=5, help_text='rate per minute', max_digits=11, verbose_name='sell rate')),
                ('r_block_min_duration', models.PositiveSmallIntegerField(default=1, verbose_name='Increment')),
                ('r_minimal_time', models.PositiveSmallIntegerField(default=0, help_text='minimal time to be billed in seconds', verbose_name='Minimal time')),
                ('r_init_block', models.DecimalField(decimal_places=5, default=0, max_digits=11, verbose_name='Connection fee')),
                ('status', models.CharField(choices=[('enabled', 'Enabled'), ('enabled_negmargin', 'Enabled allowing negative margin'), ('disabled', 'Disabled'), ('blocked', 'Blocked')], default='enabled', help_text='State of the rate : enabled / blocked - calls to this destination are blocked / disabled', max_length=20, verbose_name='Status')),
            ],
            options={
                'ordering': ('c_ratecard',),
                'db_table': 'pyfb_rating_c_country_rate',
            },
        ),
        migrations.CreateModel(
            name='CustomerCountryTypeRate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('r_rate', models.DecimalField(decimal_places=5, help_text='rate per minute', max_digits=11, verbose_name='sell rate')),
                ('r_block_min_duration', models.PositiveSmallIntegerField(default=1, verbose_name='Increment')),
                ('r_minimal_time', models.PositiveSmallIntegerField(default=0, help_text='minimal time to be billed in seconds', verbose_name='Minimal time')),
                ('r_init_block', models.DecimalField(decimal_places=5, default=0, max_digits=11, verbose_name='Connection fee')),
                ('status', models.CharField(choices=[('enabled', 'Enabled'), ('enabled_negmargin', 'Enabled allowing negative margin'), ('disabled', 'Disabled'), ('blocked', 'Blocked')], default='enabled', help_text='State of the rate : enabled / blocked - calls to this destination are blocked / disabled', max_length=20, verbose_name='Status')),
            ],
            options={
                'ordering': ('c_ratecard',),
                'db_table': 'pyfb_rating_c_countrytype_rate',
            },
        ),
        migrations.CreateModel(
            name='CustomerDefaultRate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('r_rate', models.DecimalField(decimal_places=5, help_text='rate per minute', max_digits=11, verbose_name='sell rate')),
                ('r_block_min_duration', models.PositiveSmallIntegerField(default=1, verbose_name='Increment')),
                ('r_minimal_time', models.PositiveSmallIntegerField(default=0, help_text='minimal time to be billed in seconds', verbose_name='Minimal time')),
                ('r_init_block', models.DecimalField(decimal_places=5, default=0, max_digits=11, verbose_name='Connection fee')),
                ('status', models.CharField(choices=[('enabled', 'Enabled'), ('enabled_negmargin', 'Enabled allowing negative margin'), ('disabled', 'Disabled'), ('blocked', 'Blocked')], default='enabled', help_text='State of the rate : enabled / blocked - calls to this destination are blocked / disabled', max_length=20, verbose_name='Status')),
            ],
            options={
                'ordering': ('c_ratecard',),
                'db_table': 'pyfb_rating_c_default_rate',
            },
        ),
        migrations.CreateModel(
            name='CustomerDestinationRate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('r_rate', models.DecimalField(decimal_places=5, help_text='rate per minute', max_digits=11, verbose_name='sell rate')),
                ('r_block_min_duration', models.PositiveSmallIntegerField(default=1, verbose_name='Increment')),
                ('r_minimal_time', models.PositiveSmallIntegerField(default=0, help_text='minimal time to be billed in seconds', verbose_name='Minimal time')),
                ('r_init_block', models.DecimalField(decimal_places=5, default=0, max_digits=11, verbose_name='Connection fee')),
                ('status', models.CharField(choices=[('enabled', 'Enabled'), ('enabled_negmargin', 'Enabled allowing negative margin'), ('disabled', 'Disabled'), ('blocked', 'Blocked')], default='enabled', help_text='State of the rate : enabled / blocked - calls to this destination are blocked / disabled', max_length=20, verbose_name='Status')),
            ],
            options={
                'ordering': ('c_ratecard',),
                'db_table': 'pyfb_rating_c_destination_rate',
            },
        ),
        migrations.CreateModel(
            name='CustomerPrefixRate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('r_rate', models.DecimalField(decimal_places=5, help_text='rate per minute', max_digits=11, verbose_name='sell rate')),
                ('r_block_min_duration', models.PositiveSmallIntegerField(default=1, verbose_name='Increment')),
                ('r_minimal_time', models.PositiveSmallIntegerField(default=0, help_text='minimal time to be billed in seconds', verbose_name='Minimal time')),
                ('r_init_block', models.DecimalField(decimal_places=5, default=0, max_digits=11, verbose_name='Connection fee')),
                ('status', models.CharField(choices=[('enabled', 'Enabled'), ('enabled_negmargin', 'Enabled allowing negative margin'), ('disabled', 'Disabled'), ('blocked', 'Blocked')], default='enabled', help_text='State of the rate : enabled / blocked - calls to this destination are blocked / disabled', max_length=20, verbose_name='Status')),
                ('prefix', models.CharField(db_index=True, max_length=30, verbose_name='numeric prefix')),
                ('destnum_length', models.PositiveSmallIntegerField(default=0, help_text='If value > 0, then destination number must match tsi length', verbose_name='Destination number length')),
            ],
            options={
                'ordering': ('c_ratecard',),
                'db_table': 'pyfb_rating_c_prefix_rate',
            },
        ),
        migrations.CreateModel(
            name='CustomerRatecard',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('status', model_utils.fields.StatusField(choices=[('enabled', 'Enabled'), ('disabled', 'Disabled')], default='enabled', max_length=100, no_check_for_status=True, verbose_name='status')),
                ('status_changed', model_utils.fields.MonitorField(default=django.utils.timezone.now, monitor='status', verbose_name='status changed')),
                ('description', models.TextField(blank=True, verbose_name='description')),
                ('date_start', models.DateTimeField(default=django.utils.timezone.now)),
                ('date_end', models.DateTimeField(default=pyfb_rating.models.default_time)),
                ('name', models.CharField(max_length=128, unique=True, verbose_name='name')),
                ('slug', django_extensions.db.fields.AutoSlugField(blank=True, editable=False, populate_from='name')),
                ('rc_type', models.CharField(choices=[('pstn', 'Outbound calls'), ('did', 'DID - Inbound calls'), ('pstn2did', 'Outbound calls to internal DID'), ('emergency', 'Emergency calls')], default='pstn', help_text='Select the right ratecard regarding the type of calls. Default is PSTN', max_length=10, verbose_name='Type of ratecards')),
                ('callerid_list', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='pyfb_rating.CallerNumList')),
            ],
            options={
                'ordering': ('name',),
                'db_table': 'pyfb_rating_c_ratecard',
            },
        ),
        migrations.CreateModel(
            name='CustomerRegionRate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('r_rate', models.DecimalField(decimal_places=5, help_text='rate per minute', max_digits=11, verbose_name='sell rate')),
                ('r_block_min_duration', models.PositiveSmallIntegerField(default=1, verbose_name='Increment')),
                ('r_minimal_time', models.PositiveSmallIntegerField(default=0, help_text='minimal time to be billed in seconds', verbose_name='Minimal time')),
                ('r_init_block', models.DecimalField(decimal_places=5, default=0, max_digits=11, verbose_name='Connection fee')),
                ('status', models.CharField(choices=[('enabled', 'Enabled'), ('enabled_negmargin', 'Enabled allowing negative margin'), ('disabled', 'Disabled'), ('blocked', 'Blocked')], default='enabled', help_text='State of the rate : enabled / blocked - calls to this destination are blocked / disabled', max_length=20, verbose_name='Status')),
                ('c_ratecard', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_rating.CustomerRatecard')),
                ('region', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_direction.Region')),
            ],
            options={
                'ordering': ('c_ratecard',),
                'db_table': 'pyfb_rating_c_region_rate',
            },
        ),
        migrations.CreateModel(
            name='CustomerRegionTypeRate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('r_rate', models.DecimalField(decimal_places=5, help_text='rate per minute', max_digits=11, verbose_name='sell rate')),
                ('r_block_min_duration', models.PositiveSmallIntegerField(default=1, verbose_name='Increment')),
                ('r_minimal_time', models.PositiveSmallIntegerField(default=0, help_text='minimal time to be billed in seconds', verbose_name='Minimal time')),
                ('r_init_block', models.DecimalField(decimal_places=5, default=0, max_digits=11, verbose_name='Connection fee')),
                ('status', models.CharField(choices=[('enabled', 'Enabled'), ('enabled_negmargin', 'Enabled allowing negative margin'), ('disabled', 'Disabled'), ('blocked', 'Blocked')], default='enabled', help_text='State of the rate : enabled / blocked - calls to this destination are blocked / disabled', max_length=20, verbose_name='Status')),
                ('c_ratecard', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_rating.CustomerRatecard')),
                ('region', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_direction.Region')),
                ('type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_direction.Type')),
            ],
            options={
                'ordering': ('c_ratecard',),
                'db_table': 'pyfb_rating_c_regiontype_rate',
            },
        ),
        migrations.CreateModel(
            name='ProviderCountryRate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('r_rate', models.DecimalField(decimal_places=5, help_text='rate per minute', max_digits=11, verbose_name='sell rate')),
                ('r_block_min_duration', models.PositiveSmallIntegerField(default=1, verbose_name='Increment')),
                ('r_minimal_time', models.PositiveSmallIntegerField(default=0, help_text='minimal time to be billed in seconds', verbose_name='Minimal time')),
                ('r_init_block', models.DecimalField(decimal_places=5, default=0, max_digits=11, verbose_name='Connection fee')),
                ('status', models.CharField(choices=[('enabled', 'Enabled'), ('enabled_negmargin', 'Enabled allowing negative margin'), ('disabled', 'Disabled'), ('blocked', 'Blocked')], default='enabled', help_text='State of the rate : enabled / blocked - calls to this destination are blocked / disabled', max_length=20, verbose_name='Status')),
                ('country', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_direction.Country')),
            ],
            options={
                'ordering': ('p_ratecard',),
                'db_table': 'pyfb_rating_p_country_rate',
            },
        ),
        migrations.CreateModel(
            name='ProviderCountryTypeRate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('r_rate', models.DecimalField(decimal_places=5, help_text='rate per minute', max_digits=11, verbose_name='sell rate')),
                ('r_block_min_duration', models.PositiveSmallIntegerField(default=1, verbose_name='Increment')),
                ('r_minimal_time', models.PositiveSmallIntegerField(default=0, help_text='minimal time to be billed in seconds', verbose_name='Minimal time')),
                ('r_init_block', models.DecimalField(decimal_places=5, default=0, max_digits=11, verbose_name='Connection fee')),
                ('status', models.CharField(choices=[('enabled', 'Enabled'), ('enabled_negmargin', 'Enabled allowing negative margin'), ('disabled', 'Disabled'), ('blocked', 'Blocked')], default='enabled', help_text='State of the rate : enabled / blocked - calls to this destination are blocked / disabled', max_length=20, verbose_name='Status')),
                ('country', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_direction.Country')),
            ],
            options={
                'ordering': ('p_ratecard',),
                'db_table': 'pyfb_rating_p_countrytype_rate',
            },
        ),
        migrations.CreateModel(
            name='ProviderDefaultRate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('r_rate', models.DecimalField(decimal_places=5, help_text='rate per minute', max_digits=11, verbose_name='sell rate')),
                ('r_block_min_duration', models.PositiveSmallIntegerField(default=1, verbose_name='Increment')),
                ('r_minimal_time', models.PositiveSmallIntegerField(default=0, help_text='minimal time to be billed in seconds', verbose_name='Minimal time')),
                ('r_init_block', models.DecimalField(decimal_places=5, default=0, max_digits=11, verbose_name='Connection fee')),
                ('status', models.CharField(choices=[('enabled', 'Enabled'), ('enabled_negmargin', 'Enabled allowing negative margin'), ('disabled', 'Disabled'), ('blocked', 'Blocked')], default='enabled', help_text='State of the rate : enabled / blocked - calls to this destination are blocked / disabled', max_length=20, verbose_name='Status')),
            ],
            options={
                'ordering': ('p_ratecard',),
                'db_table': 'pyfb_rating_p_default_rate',
            },
        ),
        migrations.CreateModel(
            name='ProviderDestinationRate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('r_rate', models.DecimalField(decimal_places=5, help_text='rate per minute', max_digits=11, verbose_name='sell rate')),
                ('r_block_min_duration', models.PositiveSmallIntegerField(default=1, verbose_name='Increment')),
                ('r_minimal_time', models.PositiveSmallIntegerField(default=0, help_text='minimal time to be billed in seconds', verbose_name='Minimal time')),
                ('r_init_block', models.DecimalField(decimal_places=5, default=0, max_digits=11, verbose_name='Connection fee')),
                ('status', models.CharField(choices=[('enabled', 'Enabled'), ('enabled_negmargin', 'Enabled allowing negative margin'), ('disabled', 'Disabled'), ('blocked', 'Blocked')], default='enabled', help_text='State of the rate : enabled / blocked - calls to this destination are blocked / disabled', max_length=20, verbose_name='Status')),
                ('destination', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_direction.Destination')),
            ],
            options={
                'ordering': ('p_ratecard',),
                'db_table': 'pyfb_rating_p_destination_rate',
            },
        ),
        migrations.CreateModel(
            name='ProviderPrefixRate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('r_rate', models.DecimalField(decimal_places=5, help_text='rate per minute', max_digits=11, verbose_name='sell rate')),
                ('r_block_min_duration', models.PositiveSmallIntegerField(default=1, verbose_name='Increment')),
                ('r_minimal_time', models.PositiveSmallIntegerField(default=0, help_text='minimal time to be billed in seconds', verbose_name='Minimal time')),
                ('r_init_block', models.DecimalField(decimal_places=5, default=0, max_digits=11, verbose_name='Connection fee')),
                ('status', models.CharField(choices=[('enabled', 'Enabled'), ('enabled_negmargin', 'Enabled allowing negative margin'), ('disabled', 'Disabled'), ('blocked', 'Blocked')], default='enabled', help_text='State of the rate : enabled / blocked - calls to this destination are blocked / disabled', max_length=20, verbose_name='Status')),
                ('prefix', models.CharField(db_index=True, max_length=30, verbose_name='numeric prefix')),
                ('destnum_length', models.PositiveSmallIntegerField(default=0, help_text='If value > 0, then destination number must match tsi length', verbose_name='Destination number length')),
            ],
            options={
                'ordering': ('p_ratecard',),
                'db_table': 'pyfb_rating_p_prefix_rate',
            },
        ),
        migrations.CreateModel(
            name='ProviderRatecard',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('status', model_utils.fields.StatusField(choices=[('enabled', 'Enabled'), ('disabled', 'Disabled')], default='enabled', max_length=100, no_check_for_status=True, verbose_name='status')),
                ('status_changed', model_utils.fields.MonitorField(default=django.utils.timezone.now, monitor='status', verbose_name='status changed')),
                ('description', models.TextField(blank=True, verbose_name='description')),
                ('date_start', models.DateTimeField(default=django.utils.timezone.now)),
                ('date_end', models.DateTimeField(default=pyfb_rating.models.default_time)),
                ('name', models.CharField(max_length=128, unique=True)),
                ('slug', django_extensions.db.fields.AutoSlugField(blank=True, editable=False, populate_from='name')),
                ('rc_type', models.CharField(choices=[('pstn', 'Outbound calls'), ('did', 'DID - Inbound calls'), ('pstn2did', 'Outbound calls to internal DID'), ('emergency', 'Emergency calls')], default='pstn', help_text='Select the right ratecard regarding the type of calls. Default is PSTN', max_length=10, verbose_name='Type of ratecards')),
                ('provider_prefix', models.CharField(blank=True, default='', max_length=10, verbose_name='prefix')),
                ('estimated_quality', models.PositiveSmallIntegerField(default='10', help_text='Estimated quality. Number between 0 to 10', validators=[django.core.validators.MaxValueValidator(10)], verbose_name='quality')),
                ('callerid_list', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='pyfb_rating.CallerNumList')),
            ],
            options={
                'ordering': ('name',),
                'db_table': 'pyfb_rating_p_ratecard',
            },
        ),
        migrations.CreateModel(
            name='ProviderRegionRate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('r_rate', models.DecimalField(decimal_places=5, help_text='rate per minute', max_digits=11, verbose_name='sell rate')),
                ('r_block_min_duration', models.PositiveSmallIntegerField(default=1, verbose_name='Increment')),
                ('r_minimal_time', models.PositiveSmallIntegerField(default=0, help_text='minimal time to be billed in seconds', verbose_name='Minimal time')),
                ('r_init_block', models.DecimalField(decimal_places=5, default=0, max_digits=11, verbose_name='Connection fee')),
                ('status', models.CharField(choices=[('enabled', 'Enabled'), ('enabled_negmargin', 'Enabled allowing negative margin'), ('disabled', 'Disabled'), ('blocked', 'Blocked')], default='enabled', help_text='State of the rate : enabled / blocked - calls to this destination are blocked / disabled', max_length=20, verbose_name='Status')),
                ('p_ratecard', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_rating.ProviderRatecard')),
                ('region', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_direction.Region')),
            ],
            options={
                'ordering': ('p_ratecard',),
                'db_table': 'pyfb_rating_p_region_rate',
            },
        ),
        migrations.CreateModel(
            name='ProviderRegionTypeRate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('r_rate', models.DecimalField(decimal_places=5, help_text='rate per minute', max_digits=11, verbose_name='sell rate')),
                ('r_block_min_duration', models.PositiveSmallIntegerField(default=1, verbose_name='Increment')),
                ('r_minimal_time', models.PositiveSmallIntegerField(default=0, help_text='minimal time to be billed in seconds', verbose_name='Minimal time')),
                ('r_init_block', models.DecimalField(decimal_places=5, default=0, max_digits=11, verbose_name='Connection fee')),
                ('status', models.CharField(choices=[('enabled', 'Enabled'), ('enabled_negmargin', 'Enabled allowing negative margin'), ('disabled', 'Disabled'), ('blocked', 'Blocked')], default='enabled', help_text='State of the rate : enabled / blocked - calls to this destination are blocked / disabled', max_length=20, verbose_name='Status')),
                ('p_ratecard', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_rating.ProviderRatecard')),
                ('region', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_direction.Region')),
                ('type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_direction.Type')),
            ],
            options={
                'ordering': ('p_ratecard',),
                'db_table': 'pyfb_rating_p_regiontype_rate',
            },
        ),
        migrations.AddField(
            model_name='providerprefixrate',
            name='p_ratecard',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_rating.ProviderRatecard'),
        ),
        migrations.AddField(
            model_name='providerdestinationrate',
            name='p_ratecard',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_rating.ProviderRatecard'),
        ),
        migrations.AddField(
            model_name='providerdefaultrate',
            name='p_ratecard',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_rating.ProviderRatecard'),
        ),
        migrations.AddField(
            model_name='providercountrytyperate',
            name='p_ratecard',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_rating.ProviderRatecard'),
        ),
        migrations.AddField(
            model_name='providercountrytyperate',
            name='type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_direction.Type'),
        ),
        migrations.AddField(
            model_name='providercountryrate',
            name='p_ratecard',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_rating.ProviderRatecard'),
        ),
        migrations.AddField(
            model_name='customerprefixrate',
            name='c_ratecard',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_rating.CustomerRatecard'),
        ),
        migrations.AddField(
            model_name='customerdestinationrate',
            name='c_ratecard',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_rating.CustomerRatecard'),
        ),
        migrations.AddField(
            model_name='customerdestinationrate',
            name='destination',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_direction.Destination'),
        ),
        migrations.AddField(
            model_name='customerdefaultrate',
            name='c_ratecard',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_rating.CustomerRatecard'),
        ),
        migrations.AddField(
            model_name='customercountrytyperate',
            name='c_ratecard',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_rating.CustomerRatecard'),
        ),
        migrations.AddField(
            model_name='customercountrytyperate',
            name='country',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_direction.Country'),
        ),
        migrations.AddField(
            model_name='customercountrytyperate',
            name='type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_direction.Type'),
        ),
        migrations.AddField(
            model_name='customercountryrate',
            name='c_ratecard',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_rating.CustomerRatecard'),
        ),
        migrations.AddField(
            model_name='customercountryrate',
            name='country',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pyfb_direction.Country'),
        ),
        migrations.AddIndex(
            model_name='providerregiontyperate',
            index=partial_index.PartialIndex(fields=['p_ratecard', 'region', 'type'], name='pyfb_rating_p_ratec_c60454_partial', unique=True, where="status <> 'disabled'"),
        ),
        migrations.AlterUniqueTogether(
            name='providerregiontyperate',
            unique_together={('p_ratecard', 'region', 'type')},
        ),
        migrations.AddIndex(
            model_name='providerregionrate',
            index=partial_index.PartialIndex(fields=['p_ratecard', 'region'], name='pyfb_rating_p_ratec_6ac129_partial', unique=True, where="status <> 'disabled'"),
        ),
        migrations.AlterUniqueTogether(
            name='providerregionrate',
            unique_together={('p_ratecard', 'region')},
        ),
        migrations.AddIndex(
            model_name='providerratecard',
            index=partial_index.PartialIndex(fields=['id', 'rc_type'], name='pyfb_rating_id_5d117c_partial', unique=False, where_postgresql="status = 'enabled'", where_sqlite=''),
        ),
        migrations.AddIndex(
            model_name='providerratecard',
            index=partial_index.PartialIndex(fields=['id', 'rc_type'], name='pyfb_rating_id_47a748_partial', unique=False, where="status = 'enabled' AND rc_type = 'PSTN'"),
        ),
        migrations.AddIndex(
            model_name='providerratecard',
            index=partial_index.PartialIndex(fields=['id', 'rc_type'], name='pyfb_rating_id_0bf84b_partial', unique=False, where="status = 'enabled' AND rc_type = 'DIDIN'"),
        ),
        migrations.AddIndex(
            model_name='providerratecard',
            index=partial_index.PartialIndex(fields=['id', 'rc_type'], name='pyfb_rating_id_a37e0b_partial', unique=False, where="status = 'enabled' AND rc_type = 'DIDOUT'"),
        ),
        migrations.AddIndex(
            model_name='providerratecard',
            index=partial_index.PartialIndex(fields=['id', 'rc_type'], name='pyfb_rating_id_a78fa9_partial', unique=False, where="status = 'enabled' AND rc_type = 'EMERGENCY'"),
        ),
        migrations.AddIndex(
            model_name='providerprefixrate',
            index=partial_index.PartialIndex(fields=['p_ratecard', 'prefix', 'destnum_length'], name='pyfb_rating_p_ratec_ec17e8_partial', unique=True, where="status <> 'disabled'"),
        ),
        migrations.AlterUniqueTogether(
            name='providerprefixrate',
            unique_together={('p_ratecard', 'prefix', 'destnum_length')},
        ),
        migrations.AddIndex(
            model_name='providerdestinationrate',
            index=partial_index.PartialIndex(fields=['p_ratecard', 'destination'], name='pyfb_rating_p_ratec_f9b94c_partial', unique=True, where="status <> 'disabled'"),
        ),
        migrations.AlterUniqueTogether(
            name='providerdestinationrate',
            unique_together={('p_ratecard', 'destination')},
        ),
        migrations.AddIndex(
            model_name='providerdefaultrate',
            index=models.Index(fields=['p_ratecard'], name='pyfb_rating_p_ratec_e85f44_idx'),
        ),
        migrations.AddIndex(
            model_name='providerdefaultrate',
            index=partial_index.PartialIndex(fields=['p_ratecard'], name='pyfb_rating_p_ratec_0a62fc_partial', unique=True, where="status <> 'disabled'"),
        ),
        migrations.AddIndex(
            model_name='providercountrytyperate',
            index=partial_index.PartialIndex(fields=['p_ratecard', 'country', 'type'], name='pyfb_rating_p_ratec_1beb3b_partial', unique=True, where="status <> 'disabled'"),
        ),
        migrations.AlterUniqueTogether(
            name='providercountrytyperate',
            unique_together={('p_ratecard', 'country', 'type')},
        ),
        migrations.AddIndex(
            model_name='providercountryrate',
            index=partial_index.PartialIndex(fields=['p_ratecard', 'country'], name='pyfb_rating_p_ratec_c2de1d_partial', unique=True, where="status <> 'disabled'"),
        ),
        migrations.AlterUniqueTogether(
            name='providercountryrate',
            unique_together={('p_ratecard', 'country')},
        ),
        migrations.AddIndex(
            model_name='customerregiontyperate',
            index=partial_index.PartialIndex(fields=['c_ratecard', 'region', 'type'], name='pyfb_rating_c_ratec_3b71f9_partial', unique=True, where="status <> 'disabled'"),
        ),
        migrations.AlterUniqueTogether(
            name='customerregiontyperate',
            unique_together={('c_ratecard', 'region', 'type')},
        ),
        migrations.AddIndex(
            model_name='customerregionrate',
            index=partial_index.PartialIndex(fields=['c_ratecard', 'region'], name='pyfb_rating_c_ratec_7ea5bf_partial', unique=True, where="status <> 'disabled'"),
        ),
        migrations.AlterUniqueTogether(
            name='customerregionrate',
            unique_together={('c_ratecard', 'region')},
        ),
        migrations.AddIndex(
            model_name='customerratecard',
            index=partial_index.PartialIndex(fields=['id', 'rc_type'], name='pyfb_rating_id_2b3593_partial', unique=False, where_postgresql="status = 'enabled'", where_sqlite=''),
        ),
        migrations.AddIndex(
            model_name='customerratecard',
            index=partial_index.PartialIndex(fields=['id', 'rc_type'], name='pyfb_rating_id_7ee8d2_partial', unique=False, where="status = 'enabled' AND rc_type = 'PSTN'"),
        ),
        migrations.AddIndex(
            model_name='customerratecard',
            index=partial_index.PartialIndex(fields=['id', 'rc_type'], name='pyfb_rating_id_83b1f8_partial', unique=False, where="status = 'enabled' AND rc_type = 'DIDIN'"),
        ),
        migrations.AddIndex(
            model_name='customerratecard',
            index=partial_index.PartialIndex(fields=['id', 'rc_type'], name='pyfb_rating_id_f993d1_partial', unique=False, where="status = 'enabled' AND rc_type = 'DIDOUT'"),
        ),
        migrations.AddIndex(
            model_name='customerratecard',
            index=partial_index.PartialIndex(fields=['id', 'rc_type'], name='pyfb_rating_id_8d344b_partial', unique=False, where="status = 'enabled' AND rc_type = 'EMERGENCY'"),
        ),
        migrations.AddIndex(
            model_name='customerprefixrate',
            index=partial_index.PartialIndex(fields=['c_ratecard', 'prefix', 'destnum_length'], name='pyfb_rating_c_ratec_b98511_partial', unique=True, where="status <> 'disabled'"),
        ),
        migrations.AlterUniqueTogether(
            name='customerprefixrate',
            unique_together={('c_ratecard', 'prefix', 'destnum_length')},
        ),
        migrations.AddIndex(
            model_name='customerdestinationrate',
            index=partial_index.PartialIndex(fields=['c_ratecard', 'destination'], name='pyfb_rating_c_ratec_b94a47_partial', unique=True, where="status <> 'disabled'"),
        ),
        migrations.AlterUniqueTogether(
            name='customerdestinationrate',
            unique_together={('c_ratecard', 'destination')},
        ),
        migrations.AddIndex(
            model_name='customerdefaultrate',
            index=models.Index(fields=['c_ratecard'], name='pyfb_rating_c_ratec_cda8b7_idx'),
        ),
        migrations.AddIndex(
            model_name='customerdefaultrate',
            index=partial_index.PartialIndex(fields=['c_ratecard'], name='pyfb_rating_c_ratec_e9a380_partial', unique=True, where="status <> 'disabled'"),
        ),
        migrations.AddIndex(
            model_name='customercountrytyperate',
            index=partial_index.PartialIndex(fields=['c_ratecard', 'country', 'type'], name='pyfb_rating_c_ratec_d59036_partial', unique=True, where="status <> 'disabled'"),
        ),
        migrations.AlterUniqueTogether(
            name='customercountrytyperate',
            unique_together={('c_ratecard', 'country', 'type')},
        ),
        migrations.AddIndex(
            model_name='customercountryrate',
            index=partial_index.PartialIndex(fields=['c_ratecard', 'country'], name='pyfb_rating_c_ratec_7fddda_partial', unique=True, where="status <> 'disabled'"),
        ),
        migrations.AlterUniqueTogether(
            name='customercountryrate',
            unique_together={('c_ratecard', 'country')},
        ),
    ]
